; (C) Scott Heckbert 2009 CSIRO Australia.  This code may not be copied,
; distributed, or altered without written permission from the copyright holder.
;; Copyright 2009 CSIRO Australia

extensions [ gis ]
breed [ forestry-road-finders forestry-road-finder]
breed [ hunters hunter]
breed [ road-nodes road-node ]

to startup
  clear-all
  setup-patches 
  update-view
  if output-to-text = "Yes" [set-output-file]
  do-plots
end

to setup-patches
  ask patches [ 
    set area (1)
    set moose-population ( random-float 4.4 )
    set stand-age ( random 120 )
    set isRoad? (false)
    set isCity? (false)]
end

to add-city 
  set-default-shape hunters "hunter"
  ask one-of patches with [isRoad? = true][ ; GIS
    set isCity? (true)
    sprout-hunters number-hunters [
      set my-home (patch-here) 
      ]]
  ask road-nodes [ 
   set highway-distance-to-city ( [distance myself] of  ( min-one-of patches with [isCity?] [distance myself]))]

end

to snap-roads           
set-default-shape road-nodes "circle"
   ask patches with [(isRoad? = true) and (count road-nodes-here = 0)][
    set is-main-road-patch? (true)
    sprout-road-nodes 1 [
      set parent-node (max-one-of (road-nodes-on neighbors with [is-main-road-patch? = true]) [highway-distance-to-city]); [[distance myself] of (one-of patches with [isCity? = true])]); [ distance myself ] of
      set size 0.7
      set isMainRoad? (true)
      set color red  ] ];]
  ask road-nodes [ create-links-with road-nodes-on neighbors ] 
  ask links [ set thickness 0.3 ] 
end

to Run-Model

  ; if ticks = 175 [stop]
   if ticks = 420 [stop]
  clear-drawing 
  go-home
  recalculate-distances
  if hunters-and-moose? [
    sprout-or-die
    set-type
    select-move-derive-utility
    harvest-moose
    update-hunter-congestion
    ;go-home 
    grow-moose]
  harvest-forest
  update-forestry-routes
  grow-forest
  update-view
  if output-to-text = "Yes" [write-to-file]
  do-plots
  
tick  
end

to select-move-derive-utility
  ask hunters [   
    set myPerceivedPatches n-of site-memory patches ]  ; random set of n sites percieved.
  ask hunters [ 
    ask myPerceivedPatches [ 
      set my-tc ( [tc] of myself  * travel-cost-from-city);             $   make thier perceptions  fuzzy.

      if ((moose-population >= 0) and (moose-population <= 1)) [set mp   ( [m1] of myself)]
      if ((moose-population > 1) and (moose-population <= 2)) [set mp    ([m2] of myself)]
      if ((moose-population > 2) and (moose-population <= 3)) [set mp  ([m3] of myself)]
      if ((moose-population > 3) and (moose-population <= 4)) [set mp  ([m4] of myself)]
      if ((moose-population > 4)) [set [mp] of myself   ([m5] of myself)]
      

      if ((hunter-congestion >= 0) and (hunter-congestion <= 1)) [set hc  ([c1] of myself)] ; $if cong is 8+ move these up
      if ((hunter-congestion > 1) and (hunter-congestion <= 2)) [set hc   ([c2] of myself)]
      if ((hunter-congestion > 2) and (hunter-congestion <= 3)) [set hc   ([c3] of myself)]
      if ((hunter-congestion > 3) and (hunter-congestion <= 4)) [set hc  ([c4] of myself)]
      if ((hunter-congestion > 4)) [set [hc] of myself   ([c5] of myself)]
      
      
    set patch-utility (my-tc + mp +  hc  )] 
    set selected-patch (  max-one-of myPerceivedPatches [patch-utility] )
    pen-down
    move-to selected-patch
    set utility ([patch-utility] of patch-here )]
  set total-utility (sum [utility] of hunters )
end
 
to go-home 
  ask hunters [ move-to my-home  ]
end

to sprout-or-die
  if count hunters > number-hunters [
    repeat ((count hunters) - number-hunters) [
      ask one-of hunters [die]]]
  if count hunters < number-hunters [
    ask one-of patches with [isCity? = true][ 
      sprout-hunters (number-hunters - (count hunters) ) [
        set my-home (patch-here)   ]] ]
end

to harvest-forest 
  set blocks-harvested (0);
     ask patches with [(stand-age > harvestable-stand-age) and (isRoad? = false)][  ;and this patch has forest older than the minimum cutting age, up to the quota
      if blocks-harvested < harvest-quota [
      if (count neighbors with [isRoad? ] ) > 0 [ ; if the patch has a road as a neighbor, start with ones by the road = closest
        set stand-age (1) ; cut the trees, re-setting the age
        set blocks-harvested ( blocks-harvested + 1) 
        sprout-road-nodes 1 [ ; build the road, as a series of linked nodes  
          set isMainRoad? (false)
           create-links-with road-nodes-on neighbors  ; hook up the network
            set road-age ( decomission-age ) ; new roads have a 'countdown' to being closed
            set size 0.5 
            set color green
            set parent-node (  one-of link-neighbors  with  [isMainRoad? = true] )]]] ; spot your interseation with the highway
     if blocks-harvested < harvest-quota [      
     if (( sum [count road-nodes-here] of neighbors ) >= 1 ) and (( sum [count road-nodes-here] of neighbors ) < max-road-neighbours ) [ ; this is the min and max neignbors with nodes on them, in other words how dense the cutting is. 
        set stand-age (1)
        set blocks-harvested ( blocks-harvested + 1) 
        if count road-nodes-here = 0 [ sprout-road-nodes 1 [ ; make a forestry road node
          set isMainRoad? (false)
          set  size  0.1  
          set color ( yellow )
          create-links-with road-nodes-on neighbors [  ]
          set road-age ( decomission-age ) 
          set parent-node ( one-of link-neighbors ); set it's path back to the highway
          hatch-forestry-road-finders 1 [ ; make a route finding agent ready to find the highway. 
            set location (one-of road-nodes-here )
            set home-location (location )
            set size 1
            set color ( red )]]]]]]
end


to   update-forestry-routes    
  ask forestry-road-finders [
    set distance-travelled-to-main-road 0
    let home-node-found false ; 
    while [ home-node-found = false ]  [ ; error, just repeast until all die
     if ( [ parent-node ] of location = nobody ) or ( location = nobody  ) [ ; if the parent link has died for some reason (which creates road fragments)
       ask home-location [ die ] ; kill them off
       die ]

     if (([isMainRoad?] of [ parent-node ] of location) = true) [ ; if you are back on a green node, linking to highway
       set [ distance-to-highway ] of home-location ( distance-travelled-to-main-road )
       set [ highway-distance-to-city  ] of home-location ([ highway-distance-to-city ] of ([ parent-node ] of location ));$?  one-of link-neighbors with [ highway-distance-to-city > 0];    ;  of one-of road-nodes-on neighbors with [isRoad?]  )  
       die  ]

     set new-location ( [ parent-node ] of location ) ; the forestry road finders move down a path to the highway, from 1 location to it's parent node all the way to the origin
     pen-down
     set distance-travelled-to-main-road ( distance-travelled-to-main-road + [ distance myself ] of new-location  ) ; tracking distance on the way
  
     move-to new-location
   
     set location new-location
     ask road-nodes-here [ set road-age ( decomission-age ) ]]] ; on the road finder's way, it updates the decomissioning age, so it does not hit the limit of the countdown to road decomission

  ask road-nodes [
    set road-age ( road-age - 1) 
    if isRoad?  [ 
      set road-age decomission-age ]
    if road-age < 0 [ ; age the roads to decomission age and delete when decomissed
      die]]
end


to update-hunter-congestion  
  ask patches [ 
   set hunter-congestion (( residual-congestion * 0.5 ) +  count hunters-here +   sum [count hunters-here] of neighbors   ); congestion leaves a residual of 50% of last year's value, like a memory or a reputation
   set residual-congestion ( hunter-congestion )]
end


to harvest-moose ; harvest and remove moose based on the number of hunters present
  ask patches [ set hunting-pressure  ( count hunters-here * hunter-success-rate )  ]
  ask patches [ set moose-population ( moose-population - hunting-pressure )] 
  ask patches [ 
    if  moose-population < 0 [
      set moose-population (0)]]
end

to grow-moose ; moose grow using a logistic equations. the r growth rate is in the GUI
ask patches [
  set moose-population (moose-population + (moose-growth-rate * ( moose-population * ( 1 - (moose-population / moose-carrying-capacity))) ));
  if moose-population = 0 [ ; where extirpated areas are re-populated take some moose out of the neighbour with max moose
    let nbMPop ( max-one-of neighbors [moose-population] ) 
    set moose-population ( tranfer-rate-from-neighbors * [moose-population] of nbMPop  )
    ask nbMPop [ set moose-population ( moose-population - ( tranfer-rate-from-neighbors * moose-population))]]]
end

to   grow-forest
ask patches [
  set stand-age (stand-age + 1)
  if ( stand-age > 120 ) [
    set stand-age ( 120 )]]
end

to recalculate-distances ; this aportions distance to length via roads,each patch calculates it's distance back to the city. from through the forest, to down the forestry road, to the higheway to city. 
 

  ask patches [
    set patch-distance-in-forest ( 0 );  distance is comprised of 3 types of travel, forest, forestry road, and highway.
    set travel-cost-from-city (0)
    ifelse count road-nodes-here = 0 [ 
      set nearest-node ( min-one-of road-nodes [distance myself])
      set patch-distance-in-forest ( [ distance myself ] of nearest-node  ) ][; distance in forest][
        set nearest-node (one-of road-nodes-here)
        set patch-distance-in-forest (0)]; find nearest road
    set distance-highway (0)
    set distance-foretry-roads ([distance-to-highway] of nearest-node)
    set distance-highway ([highway-distance-to-city] of nearest-node)
    
    if isRoad? [
      set distance-foretry-roads ([distance-to-highway] of one-of road-nodes-here)
    
]
    set travel-cost-from-city ( (Forest-Travel-Cost * patch-distance-in-forest + Forestry-Road-Travel-Cost * distance-foretry-roads + Highway-Travel-Cost * distance-highway) )]
end

  
to road-draw
  if mouse-down? [
      ask patch mouse-xcor mouse-ycor
        [ set isRoad? (true)
          set pcolor red]]
end

to do-plots
 set-current-plot "Utility"
 set-current-plot-pen "total-utility"
 plot total-utility
 
 set-current-plot "Blocks-harvested"
 set-current-plot-pen "blocks-harvested"
 plot blocks-harvested
 
 set-current-plot "Extirpations"
 set-current-plot-pen "moose-extirpations"
 plot count patches with [moose-population = 0]
end

to update-view  
 if View =  "Forest-Age" [ ask patches [ set pcolor scale-color green stand-age 130 -100 ]] 
 if View =  "Moose-Population" [ ask patches [ set pcolor scale-color blue moose-population 4.4 0 ]] ; can flip between views
 if View =  "Hunter-Congestion" [ ask patches [ set pcolor scale-color yellow hunter-congestion 2 -0]] 
 if View =  "Travel-Cost" [ 
   ask patches with [travel-cost-from-city > 0 ][
       let max-TC ( [travel-cost-from-city] of max-one-of patches [travel-cost-from-city]  )
       set pcolor scale-color yellow travel-cost-from-city max-TC -100 ]]
end

to make-movie
  user-message "Choose .mov file"
  let path user-new-file
  if not is-string? path [ stop ] 
  startup 
  movie-start path
  movie-grab-view
  while [ ticks < 200 ]
    [ Run-Model
      movie-grab-view ]
  movie-close
end

globals[
  roads-dataset
  FMA-dataset
  blocks-harvested 
  total-utility
  cities
]

forestry-road-finders-own[
  location
  home-location
  new-location
  distance-travelled-to-main-road
]

road-nodes-own [
  road-age
  parent-node
  distance-to-highway
  highway-distance-to-city
  isMainRoad?
  highway-node
]

hunters-own [
  selected-patch
  myPerceivedPatches 
  my-home
  intercept
  utility
  utility-coeff-travel-cost

  tc
  m1
  m2
  m3
  m4
  m5
  c1
  c2
  c3
  c4
  c5
]

patches-own [
  ;fma-id
  my-tc
  mp
  hc
  hunting-pressure
  area
  moose-population
  stand-age
  access-level
  hunter-congestion
  isCity?
  isRoad?
  is-main-road-patch?
  patch-distance-in-forest
  distance-foretry-roads
  distance-highway
  nearest-node
  travel-cost-from-city
  residual-congestion 
  patch-utility
]

to set-output-file
 file-close
 let file user-new-file
  if is-string? file [
    if file-exists? file
      [ file-delete file ]
    file-open file
    write-to-file 
  ]
end

to write-to-file
  file-print (word ticks " , "
  ; other variables
  (count patches with [moose-population = 0]) " , "
  
  total-utility " , "
  Hunter-Type " , "
  
  
  )
end

to set-type
  ask hunters [ 
   if Hunter-Type = "Ontario-Rec" [
        set tc (  -0.008  )
        set m1 (  -0.49  )
        set m2 (  0.15  )
        set m3 (   0.15 )
        set m4 (  0.85  )  
        set m5 (  0.85  )
        set c1 ( 0.55   )
        set c2 (-0.003    )
        set c3 ( -0.003   )
        set c4 (   -0.003 )  
        set c5 (   -0.55 )  ]
  if Hunter-Type = "Alberta-Rural" [
        set tc (  -0.0125  )
        set m1 ( -1.41   )
        set m2 (  -1.41  )
        set m3 (  0.22  )
        set m4 ( 0.22   )  
        set m5 (  0.22  )
        set c1 ( 0.72   )
        set c2 (  0.72  )
        set c3 (  0.02  )
        set c4 (  0.02  )  
        set c5 (  0.02  )      ]
 if Hunter-Type = "Sask-First-Nations" [
        set tc (  -0.0078  )
        set m1 ( -1.04  )
        set m2 ( -1.04 )
        set m3 (  0.24  )
        set m4 ( 0.24   )  
        set m5 (  0.24  )
        set c1 (   0.76   )
        set c2 (    0.76  )
        set c3 (  -0.10  )
        set c4 (  -0.10  )  
        set c5 (  -0.10  )      ]
  if Hunter-Type = "Alberta-Rec" [
        set tc ( -0.0056 )
        set m1 ( -0.7  )
        set m2 ( -0.06 )
        set m3 (  0.06  )
        set m4 ( 0.44   )  
        set m5 (  0.44  )
        set c1 (   0.60   )
        set c2 (    0.60  )
        set c3 (  0.07  )
        set c4 (  0.07)  
        set c5 ( -0.28  )      ]
  if Hunter-Type = "Alberta-Metis" [
        set tc ( -0.01 )
        set m1 ( -0.30  )
        set m2 ( -0.18 )
        set m3 (  -0.15  )
        set m4 ( 0.50   )  
        set m5 (  0.50  )
        set c1 (   0   )
        set c2 (  -0.33 )
        set c3 (  -0.33 )
        set c4 (  -0.33)  
        set c5 ( -0.33 )      ]
   if Hunter-Type = "Alberta-First-Nations" [
        set tc ( -0.004 )
        set m1 (-0.25 )
        set m2 ( -0.20)
        set m3 (  -0.15 )
        set m4 ( 0.50   )  
        set m5 (  0.50  )
        set c1 (   0   )
        set c2 (  -0.33 )
        set c3 (  -0.33 )
        set c4 (  -0.33)  
        set c5 ( -0.33 )  ]

   if Hunter-Type = "Average-Agent" [
        set tc ( -0.008)
        set m1 (-0.70 )
        set m2 ( -0.46)
        set m3 (  -0.04)
        set m4 ( 0.46   )  
        set m5 (  0.46  )
        set c1 (   0.44  )
        set c2 (  0.24)
        set c3 (  -0.12)
        set c4 (  -0.12)  
        set c5 ( -0.27 )   ]]
 end     
      
 
; (C) Scott Heckbert 2009 CSIRO Australia.  This code may not be copied,
; distributed, or altered without written permission from the copyright holder.
;
; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
; "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
; LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
; A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT
; OWNERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
; SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
; LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
; DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
; (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
; OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

@#$#@#$#@
GRAPHICS-WINDOW
285
10
1000
746
70
70
5.0
1
10
1
1
1
0
1
1
1
-70
70
-70
70
0
0
1
ticks

CC-WINDOW
5
760
1172
855
Command Center
0

BUTTON
7
10
79
43
NIL
startup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
7
51
83
84
Run-Model
Run-Model
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
150
148
280
181
harvestable-stand-age
harvestable-stand-age
0
150
63
1
1
NIL
HORIZONTAL

SLIDER
150
184
281
217
harvest-quota
harvest-quota
0
250
54
1
1
NIL
HORIZONTAL

PLOT
1002
261
1162
381
Blocks-harvested
time
blocks-harvested
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"blocks-harvested" 1.0 0 -16777216 true

CHOOSER
158
53
284
98
View
View
"Moose-Population" "Forest-Age" "Hunter-Congestion" "Travel-Cost"
1

BUTTON
82
10
143
43
NIL
road-draw
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
1002
11
1163
131
Utility
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"total-utility" 1.0 0 -16777216 true

SLIDER
150
350
282
383
moose-carrying-capacity
moose-carrying-capacity
0
7
4.4
0.2
1
m/km
HORIZONTAL

SLIDER
150
313
282
346
moose-growth-rate
moose-growth-rate
0
0.5
0.02
0.01
1
NIL
HORIZONTAL

SLIDER
11
183
124
216
hunter-success-rate
hunter-success-rate
0
5
0.7
0.005
1
NIL
HORIZONTAL

SLIDER
152
253
281
286
decomission-age
decomission-age
0
20
5
1
1
NIL
HORIZONTAL

SLIDER
12
289
149
322
Travel-cost-MU
Travel-cost-MU
-0.2
0
-0.0020
0.001
1
NIL
HORIZONTAL

SLIDER
150
387
282
420
tranfer-rate-from-neighbors
tranfer-rate-from-neighbors
0
0.1
0
0.005
1
NIL
HORIZONTAL

SLIDER
13
569
147
602
Forestry-Road-Travel-Cost
Forestry-Road-Travel-Cost
0
10
1.4
0.01
1
NIL
HORIZONTAL

SLIDER
14
605
148
638
Highway-Travel-Cost
Highway-Travel-Cost
0
10
1.39
0.01
1
NIL
HORIZONTAL

SLIDER
13
534
147
567
Forest-Travel-Cost
Forest-Travel-Cost
0
10
2.48
0.01
1
NIL
HORIZONTAL

BUTTON
13
645
85
678
NIL
make-movie
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

TEXTBOX
11
128
96
151
Hunter settings
11
0.0
1

TEXTBOX
155
130
255
153
Forestry settings
11
0.0
1

TEXTBOX
154
295
233
318
Game settings
11
0.0
1

TEXTBOX
13
273
171
297
Hunter Utility Function
11
0.0
1

BUTTON
83
51
155
85
NIL
update-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
14
469
120
502
site-memory
site-memory
1
100
26
1
1
NIL
HORIZONTAL

MONITOR
1005
383
1058
428
#hunters
count hunters
0
1
11

PLOT
1002
135
1162
255
Extirpations
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"moose-extirpations" 1.0 0 -16777216 true

CHOOSER
7
218
131
263
Hunter-Type
Hunter-Type
"Average-Agent" "Ontario-Rec" "Alberta-Rec" "Alberta-First-Nations" "Alberta-Metis" "Sask-First-Nations" "Alberta-Rural"
1

SLIDER
11
146
125
179
number-hunters
number-hunters
0
100
80
1
1
NIL
HORIZONTAL

SLIDER
13
327
149
360
Moose-MU
Moose-MU
-1
1
0.7
0.01
1
NIL
HORIZONTAL

SLIDER
12
364
148
397
Congestion-MU
Congestion-MU
-1
1
-0.44
0.01
1
NIL
HORIZONTAL

SLIDER
13
399
119
432
preference-param-stdev
preference-param-stdev
0
100
10
1
1
%
HORIZONTAL

SLIDER
13
434
119
467
perception-accuracy
perception-accuracy
0
100
95
1
1
NIL
HORIZONTAL

BUTTON
143
10
205
43
snap-roads
snap-roads
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
203
10
260
43
add-city
add-city
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
150
218
280
251
max-road-neighbours
max-road-neighbours
0
6
3
1
1
NIL
HORIZONTAL

TEXTBOX
15
515
165
533
Travel Cost
11
0.0
1

SWITCH
12
93
120
126
hunters-and-moose?
hunters-and-moose?
0
1
-1000

CHOOSER
143
426
281
471
output-to-text
output-to-text
"Yes" "No"
1

@#$#@#$#@
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

hunter
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -2674135 true false 60 196 90 211 114 155 120 196 180 196 187 158 210 211 240 196 195 91 165 91 150 106 150 135 135 91 105 91
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -6459832 true false 174 90 181 90 180 195 165 195
Polygon -13345367 true false 180 195 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285
Polygon -6459832 true false 126 90 119 90 120 195 135 195
Rectangle -6459832 true false 45 180 255 195
Line -16777216 false 135 165 165 165
Line -16777216 false 135 135 165 135
Line -16777216 false 90 135 120 135
Line -16777216 false 105 120 120 120
Line -16777216 false 180 120 195 120
Line -16777216 false 180 135 210 135
Line -16777216 false 90 150 105 165
Line -16777216 false 225 165 210 180
Line -16777216 false 75 165 90 180
Line -16777216 false 210 150 195 165
Line -16777216 false 180 105 210 180
Line -16777216 false 120 105 90 180
Line -16777216 false 150 135 150 165
Polygon -2674135 true false 100 30 104 44 189 24 185 10 173 10 166 1 138 -1 111 3 109 28
Polygon -16777216 true false 210 180 225 195 300 210 300 180 210 180

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person lumberjack
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -2674135 true false 60 196 90 211 114 155 120 196 180 196 187 158 210 211 240 196 195 91 165 91 150 106 150 135 135 91 105 91
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -6459832 true false 174 90 181 90 180 195 165 195
Polygon -13345367 true false 180 195 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285
Polygon -6459832 true false 126 90 119 90 120 195 135 195
Rectangle -6459832 true false 45 180 255 195
Polygon -16777216 true false 255 165 255 195 240 225 255 240 285 240 300 225 285 195 285 165
Line -16777216 false 135 165 165 165
Line -16777216 false 135 135 165 135
Line -16777216 false 90 135 120 135
Line -16777216 false 105 120 120 120
Line -16777216 false 180 120 195 120
Line -16777216 false 180 135 210 135
Line -16777216 false 90 150 105 165
Line -16777216 false 225 165 210 180
Line -16777216 false 75 165 90 180
Line -16777216 false 210 150 195 165
Line -16777216 false 180 105 210 180
Line -16777216 false 120 105 90 180
Line -16777216 false 150 135 150 165
Polygon -2674135 true false 100 30 104 44 189 24 185 10 173 10 166 1 138 -1 111 3 109 28

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
